# gauss-jordan-assistant

Enabling live demonstration of the Gauss-Jordan algorithm in a terminal/console.

## Requirements

- Python 3.8+
- Rich (https://pypi.org/project/rich/)

To work properly on Windows (which is what I use), you need the following:

- Windows Terminal (https://github.com/Microsoft/Terminal)

## Description

The idea of this project is to enable live demonstration of using the Gauss-Jordan algorithm to solve systems of linear equations, using a simple console. This project is developed on Windows but should work using other operating systems.

Commands will include:
    - Defining the size of a matrix; number of rows limited to 9.
    - Entering its row
    - Using elementary row operations to transform the matrix
    - Optionnally, save the entire process using LaTeX syntax.


English and French are supported.

